import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class NoKeyboardEditableText extends EditableText {

  NoKeyboardEditableText({
    TextEditingController controller,
    TextStyle style = const TextStyle(color: Colors.black),
    Color cursorColor = Colors.black,
    bool autofocus = false,
    Color selectionColor,
    ValueChanged<String> onChanged,
    VoidCallback onEditingComplete,
    ValueChanged<String> onSubmitted,
    SelectionChangedCallback onSelectionChanged,
  }):super(
      controller: controller ?? TextEditingController(),
      focusNode: NoKeyboardEditableTextFocusNode(),
      backgroundCursorColor: Colors.grey,
      style: style,
      cursorColor: cursorColor,
      autofocus: autofocus,
      selectionColor: selectionColor,
      onChanged: onChanged,
      onEditingComplete: onEditingComplete,
      onSubmitted: onSubmitted,
      onSelectionChanged: onSelectionChanged,
  );

  @override
  EditableTextState createState() {
    return NoKeyboardEditableTextState();
  }

}

class NoKeyboardEditableTextState extends EditableTextState {
  @override
  void requestKeyboard() {
    //super.requestKeyboard(); // don't call the super method
    //just request focus
    FocusScope.of(context).requestFocus(new FocusNode());
//    FocusScope.of(context).requestFocus(widget.focusNode);
  }
//  @override
//  void requestKeyboard() {
//    super.requestKeyboard();
//    //hide keyboard
//    SystemChannels.textInput.invokeMethod('TextInput.hide');
//  }
}

class NoKeyboardEditableTextFocusNode extends FocusNode {
  @override
  bool consumeKeyboardToken() {
    // prevents keyboard from showing on first focus
    Future.delayed(Duration(milliseconds: 10), ()=> SystemChannels.textInput.invokeMethod('TextInput.hide'));
    return true;
  }
}